@@ -328,8 +328,15 @@ try {
             }
             
         } catch (Exception $e) {
-            logMessage("Error processing schedule $scheduleId: " . $e->getMessage(), 'ERROR');
+            $errorMessage = "Scheduled backup failed for user: $user - " . $e->getMessage();
+            logMessage($errorMessage, 'ERROR');
             $scheduledFailed++;
+
+            // If we get a database integrity constraint error, it means we tried to insert null
+            // into the backup_history status field. Log this as a specific issue
+            if (strpos($e->getMessage(), 'Column \'status\' cannot be null') !== false) {
+                error_log("CRITICAL: Backup scheduler attempted to create backup_history with null status for user $user");
+            }
         }
         
         // Update next run time
@@ -444,11 +451,15 @@ try {
             }
             
         } catch (Exception $e) {
-            logMessage("Error processing queued backup $queueId: " . $e->getMessage(), 'ERROR');
-            
-            // Mark as failed
+            $errorMessage = $e->getMessage();
+            logMessage("Error processing queued backup $queueId: " . $errorMessage, 'ERROR');
+
+            // Mark as failed - ensure error message is never null
+            if (empty($errorMessage)) {
+                $errorMessage = "Unknown error occurred during backup";
+            }
             $stmt = $db->prepare("UPDATE backup_queue SET status = 'failed', completed_at = NOW(), error_message = ? WHERE id = ?");
-            $stmt->execute([$e->getMessage(), $queueId]);
+            $stmt->execute([$errorMessage, $queueId]);
             $queuedFailed++;
         }
     }
