@@ -508,6 +508,8 @@ echo "Setting up backup system cron jobs..."
 (crontab -l 2>/dev/null; echo "0 2 * * * /usr/bin/php /root/whp/scripts/cleanup-backups.php >/dev/null 2>&1") | crontab -
 (crontab -l 2>/dev/null; echo "# WHP Backup System - Process scheduled backups every 5 minutes") | crontab -
 (crontab -l 2>/dev/null; echo "*/5 * * * * /usr/bin/php /root/whp/scripts/backup-scheduler.php >/dev/null 2>&1") | crontab -
+(crontab -l 2>/dev/null; echo "# WHP Backup System - Process pending backup creations every minute") | crontab -
+(crontab -l 2>/dev/null; echo "* * * * * /usr/bin/php /docker/whp/web/scripts/backup-worker.php >/dev/null 2>&1") | crontab -
 
 echo "✓ Backup system cron jobs configured"
 
